%define shortVersion %(echo %{version} | cut -d. -f1,2)

Name: cmake
Summary: Cross-platform, open-source make system
Version: 2.4.8
Release: %mkrel 1
License: BSD
Group: Development/Other
Epoch: 1
Url: http://www.cmake.org/HTML/Index.html
Source: http://www.cmake.org/files/v%{shortVersion}/%name-%{version}.tar.gz
Source1: cmake.macros
# fix vtk 5.0 detection
Patch0: cmake-vtk-5.0.patch
# fix ftlk detection
Patch1: cmake-fltk-path.patch
Patch2: cmake-wx-config.patch
Patch3: cmake-expat.patch
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-buildroot
BuildRequires: chrpath
BuildRequires: perl
BuildRequires: ncurses-devel

%description
CMake is used to control the software compilation process using
simple platform and compiler independent configuration files.
CMake generates native makefiles and workspaces that can be
used in the compiler environment of your choice. CMake is quite
sophisticated: it is possible to support complex environments
requiring system configuration, pre-processor generation, code
generation, and template instantiation.

%prep

%setup -q -n %name-%{version}

%patch0
%patch1
%patch2 -p1
%patch3 -p1

%if "%{_lib}" != "lib"
perl -pi -e 's#usr/lib#usr/lib64#' `find -type f`
perl -pi -e 's#/usr/X11R6/lib#/usr/X11R6/lib64#' `find -type f`
%endif

%build
./configure \
   --prefix=%{_prefix} \
   --mandir=/share/man

%make

%install
rm -rf %buildroot
make install DESTDIR=%buildroot

# cmake mode for emacs
install -d %buildroot%_datadir/emacs/site-lisp/
install -m644 Docs/cmake-mode.el %buildroot%_datadir/emacs/site-lisp/
install -d %buildroot%_sysconfdir/emacs/site-start.d
cat <<EOF >%buildroot%_sysconfdir/emacs/site-start.d/%{name}.el
(setq load-path (cons (expand-file-name "/dir/with/cmake-mode") load-path))
(require 'cmake-mode)
(setq auto-mode-alist
      (append '(("CMakeLists\\\\.txt\\\\'" . cmake-mode)
                ("\\\\.cmake\\\\'" . cmake-mode))
              auto-mode-alist))
EOF

install -d -m 755 %buildroot%_sysconfdir/rpm/macros.d/
install -m 644 %SOURCE1 %buildroot%_sysconfdir/rpm/macros.d/
for name in Docs/ctest.1 Docs/cmake.1 Docs/ccmake.1 Docs/cmake-mode.el Docs/cmake-indent.vim Docs/cmake-syntax.vim; do
    rm -f ${name}
done

%clean
rm -rf %buildroot

%files
%defattr(-,root,root)
%_bindir/cmake
%_bindir/ccmake
%_bindir/ctest
%_bindir/cpack
%_mandir/man1/*
%_datadir/cmake-%shortVersion/
%_sysconfdir/emacs/site-start.d/%{name}.el
%_sysconfdir/rpm/macros.d/*
%_datadir/emacs/site-lisp/cmake-mode.el
%doc CMakeLogo.gif ChangeLog.txt Docs/* Example
%exclude %_prefix/doc


%changelog
* Fri Feb 08 2008 Helio Chissini de Castro <helio@mandriva.com> 1:2.4.8-1mdv2008.1
+ Revision: 164160
- Reverting cmake for stable 2.4.8. KDE 4 assume > 2.4.5 and going to devel version is leading to some unexpected path bad behavior.
- Patches from expat and wx was backported

* Wed Feb 06 2008 Helio Chissini de Castro <helio@mandriva.com> 2.5.0-0.20080106.1mdv2008.1
+ Revision: 163028
- Update to more recent CVS snapshot
- Removed already applied upstream expat and wx patches

* Wed Jan 30 2008 Giuseppe Ghibò <ghibo@mandriva.com> 2.5.0-0.20071024.3mdv2008.1
+ Revision: 160292
- Fix expat detection (bug CMake#6062).

* Tue Jan 08 2008 Olivier Blin <oblin@mandriva.com> 2.5.0-0.20071024.2mdv2008.1
+ Revision: 146562
- fix wx-config output being flattened
- restore BuildRoot

  + Thierry Vignaud <tvignaud@mandriva.com>
    - kill re-definition of %%buildroot on Pixel's request

* Wed Oct 24 2007 Nicolas Lécureuil <neoclust@mandriva.org> 2.5.0-0.20071024.1mdv2008.1
+ Revision: 101840
- Update to cvs snapshot (because kde4 needs it)

  + Thierry Vignaud <tvignaud@mandriva.com>
    - replace %%_datadir/man by %%_mandir!

* Thu Jul 19 2007 Funda Wang <fundawang@mandriva.org> 2.4.7-1mdv2008.0
+ Revision: 53410
- New version

  + Helio Chissini de Castro <helio@mandriva.com>
    - Add rpm macros for cmake. Thanks to Anssi Hannula for point this ones.


* Tue Jan 23 2007 Gustavo De Nardin <gustavodn@mandriva.com> 2.4.6-2mdv2007.0
+ Revision: 112566
- don't double package some documentation files
- install emacs mode

* Fri Jan 12 2007 Laurent Montel <lmontel@mandriva.com> 2.4.6-1mdv2007.1
+ Revision: 107768
- 2.4.6

* Tue Jan 09 2007 Laurent Montel <lmontel@mandriva.com> 2.4.6-0.rc2.1mdv2007.1
+ Revision: 106621
- 2.4.6-rc2

* Tue Dec 05 2006 Laurent Montel <lmontel@mandriva.com> 2.4.5-1mdv2007.1
+ Revision: 90681
- 2.4.5

* Tue Nov 21 2006 Laurent Montel <lmontel@mandriva.com> 2.4.4-1mdv2007.1
+ Revision: 85881
- 2.4.4

  + Gaëtan Lehmann <glehmann@mandriva.org>
    - fix fltk detection (patch 1)

* Wed Aug 02 2006 Laurent Montel <lmontel@mandriva.com> 2.4.3-2mdv2007.0
+ Revision: 42884
- New release 2.4.3 (2006/08/01)
- 2.4.3
- 2.4.2

  + Andreas Hasenack <andreas@mandriva.com>
    - renamed mdv to packages because mdv is too generic and it's hosting only packages anyway

  + Gaëtan Lehmann <glehmann@mandriva.org>
    - update release tag
    - fix vtk 5.0 detection

  + Helio Chissini de Castro <helio@mandriva.com>
    - Added the current source
    - New Cmake 2.4.1 beta. Required for current KDE 4 development
    - Added cmake on subversion. Gaetan, current maintainer was already notified and now, since kde 4 move development pro cmake and Laurent, me and Boiko will need cmake up to date

* Sat Mar 25 2006 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 2.3.4-0.20060321.2mdk
- lib -> lib64 on x86_64 - the fix in cmake is not enough

* Tue Mar 21 2006 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 2.3.4-0.20060321.1mdk
- 2.3.4 (snapshot 20060321)

* Wed Mar 15 2006 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 2.3.4-0.20060315.2mdk
- build requires

* Wed Mar 15 2006 Laurent MONTEL <lmontel@mandriva.com> 2.3.4-0.20060315.1mdk
- 2.3.4 (snapshot 20060315)

* Sun Mar 12 2006 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 2.3.4-0.20060312.1mdk
- 2.3.4 (snapshot 20060312)

* Sun Feb 12 2006 Laurent MONTEL <lmontel@mandriva.com> 2.3.3
- 2.3.3 (snapshot 20060210)

* Fri Feb 10 2006 Laurent MONTEL <lmontel@mandriva.com> 2.3.2
- 2.3.2 version (snapshot 20060209)

* Fri Feb 03 2006 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 2.2.3-3mdk
- fix kde search path

* Sun Jan 22 2006 Laurent MONTEL <lmontel@mandriva.com> 2.2.3-2mdk
- Fix spec file. I don't understand how a 2.2.2 spec file was integrate into 2.2.3 package (nobody couldn't rebuild it)

* Fri Nov 04 2005 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 2.2.2-1mdk
- New release 2.2.2

* Thu Oct 20 2005 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 2.2.1-1mdk
- New release 2.2.1

* Tue Jul 19 2005 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 2.2.0-1mdk
- 2.2.0
- make it more rpmbuildupdatable
- buildrequires ncurses-devel
- list files in bindir to be sure that ccmake is built

* Fri Jun 10 2005 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 2.0.6-3mdk
- also fix X11 lib path on x86_64

* Fri Jun 10 2005 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 2.0.6-2mdk
- fix lib path to make ccmake compile on x86_64. It should also help
  to find lib with this arch

* Wed Apr 27 2005 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 2.0.6-1mdk
- New release 2.0.6
- use mkrel

* Fri Mar 11 2005 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 2.0.5-2mdk
- fix some lint
- add examples in docs

* Tue Nov 23 2004 Gaetan LEHMANN <gaetan.lehmann@jouy.inra.fr> 2.0.5-1mdk
- 2.0.5

* Wed Jun 16 2004 Laurent MONTEL <lmontel@mandrakesoft.com> 1.6.7-2mdk
- Rebuild

